@@ -74,9 +74,9 @@ def getContainerStatements(graph, source, predicate):
         raise ValueError("Expected only one value for {0}".format(predicate))
 
 def getContainerItems(graph, node, predicate):
-    return [s[2] for s in getContainerStatements(graph, node, predicate)]
+    statements = getContainerStatements(graph, node, predicate)
+    return [statement[2] for statement in statements] if statements else None
 
-# Borrowed, with modifications, from xmptools (for now)
 def setContainerItems(graph, node, predicate, values, newtype=RDF.Seq):
     # Having to write code like this is a clear indication that triples are the wrong
     # abstraction for graphs, way too low level. Just sayin'.
